@@ -44,6 +44,7 @@
 #include "window.h"
 #include "game.h"
 #include "util.h"
+#include "ar-application.h"
 
 #if 0
 /* String reserve */
@@ -53,7 +54,6 @@ N_("About Solitaire")
 #endif /* 0 */
 
 typedef struct {
-  AisleriotWindow *window;
   char *variation;
   gint seed; /* unused */
   gboolean freecell;
@@ -87,6 +87,8 @@ main_prog (void *closure, int argc, char *argv[])
   GOptionContext *option_context;
   GError *error = NULL;
   gboolean retval;
+  GtkApplication *application;
+  int status G_GNUC_UNUSED;
 
   memset (&data, 0, sizeof (AppData));
 
@@ -95,8 +97,6 @@ main_prog (void *closure, int argc, char *argv[])
 
   add_main_options (option_context, &data);
 
-  ar_sound_enable (FALSE);
-
   g_option_context_add_group (option_context, gtk_get_option_group (TRUE));
 
 #ifdef HAVE_CLUTTER
@@ -141,31 +141,15 @@ main_prog (void *closure, int argc, char *argv[])
 
   g_assert (data.variation != NULL || data.freecell);
 
-  ar_stock_init ();
-
-  gtk_window_set_default_icon_name (data.freecell ? "gnome-freecell" : "gnome-aisleriot");
-
-  data.window = AISLERIOT_WINDOW (aisleriot_window_new (data.freecell));
-  g_signal_connect (data.window, "destroy",
-		    G_CALLBACK (gtk_main_quit), NULL);
-
-  if (data.freecell) {
-    aisleriot_window_set_game_module (data.window, FREECELL_VARIATION, NULL);
-  } else {
-    aisleriot_window_set_game_module (data.window, data.variation, NULL);
-  }
-
-  gtk_window_present (GTK_WINDOW (data.window));
-
-  gtk_main ();
+  application = ar_application_new (data.variation, data.freecell);
+  status = g_application_run (G_APPLICATION (application), 0, NULL);
+  g_object_unref (application);
 
   aisleriot_conf_shutdown ();
 
 cleanup:
   g_free (data.variation);
 
-  g_settings_sync ();
-
   ar_runtime_shutdown ();
 }
 
